# Comical JPEG Compressor

Make your funny images look like how you feel on the inside.

## Installation

```bash
pip install morejpeg
```

## Usage

```bash
morejpeg what.png
morejpeg what.png --passes 10
```
